package com.pokkt.wrapper.thirdparty.AdMob;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;
import android.widget.RelativeLayout;

import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.AdSize;
import com.google.android.gms.ads.mediation.MediationAdRequest;
import com.google.android.gms.ads.mediation.customevent.CustomEventBanner;
import com.google.android.gms.ads.mediation.customevent.CustomEventBannerListener;
import com.pokkt.PokktAds;
import com.pokkt.sdk.banners.PokktBannerView;

import org.json.JSONObject;

public class PokktCustomBanner implements CustomEventBanner, PokktAds.Banner.BannerAdDelegate {

    private final String TAG = "PokktAdMobWrapperBanner";
    private CustomEventBannerListener bannerListener = null;
    private PokktBannerView pokktBannerView;
    private String screenName = "Default";
    private String appId;
    private String secKey;
    private String thirdPartyUserid;
    private boolean isDebug = true;

    @Override
    public void onDestroy() {
        if (isDebug) {
            Log.i(TAG, " Destroy banner ad");
        }
        if (pokktBannerView != null) {
            PokktAds.Banner.destroy(pokktBannerView);
            pokktBannerView = null;
        }
    }

    @Override
    public void onPause() {

    }

    @Override
    public void onResume() {

    }

    @Override
    public void requestBannerAd(Context context, CustomEventBannerListener listener, String serverParameter, AdSize adSize, MediationAdRequest mediationAdRequest, Bundle bundle) {
        try {
            if (!TextUtils.isEmpty(serverParameter)) {
                JSONObject serverExtraObj = new JSONObject(serverParameter);
                screenName = serverExtraObj.optString("POKKT_SCREEN_NAME", "Default").trim();
                appId = serverExtraObj.optString("POKKT_APP_ID", "").trim();
                secKey = serverExtraObj.optString("POKKT_SEC_KEY", "").trim();
                thirdPartyUserid = serverExtraObj.optString("POKKT_THIRD_PARTY_USERID", "12345").trim();
                isDebug = serverExtraObj.optBoolean("POKKT_DEBUG", true);
            }
        } catch (Throwable t) {
            if (isDebug) {
                Log.e(TAG, "Failed to parse server parameters: " + serverParameter);
            }
        }
        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
            Log.e(TAG, "Invalid details. Abort request");
            return;
        }
        if (isDebug) {
            Log.i(TAG, " Request banner ad");
        }
        bannerListener = listener;
        PokktAds.setPokktConfig(appId, secKey, (Activity) context);
        PokktAds.setThirdPartyUserId(thirdPartyUserid);
        PokktAds.Debugging.shouldDebug(context, isDebug);
        pokktBannerView = new PokktBannerView(context);
        RelativeLayout.LayoutParams layoutParams = new RelativeLayout.LayoutParams(adSize.getWidth(), adSize.getHeight());
        pokktBannerView.setLayoutParams(layoutParams);
        PokktAds.Banner.setDelegate(this);
        PokktAds.Banner.loadBanner(screenName, pokktBannerView);
    }

    @Override
    public void bannerLoaded(String screenName) {
        if (isDebug) {
            Log.i(TAG, " Banner loaded");
        }
        if (PokktCustomBanner.this.bannerListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomBanner.this.bannerListener.onAdLoaded(pokktBannerView);
                }
            });
        }
    }

    @Override
    public void bannerLoadFailed(String screenName, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, " Banner load failed " + errorMessage);
        }
        if (PokktCustomBanner.this.bannerListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomBanner.this.bannerListener.onAdFailedToLoad(AdRequest.ERROR_CODE_NO_FILL);
                }
            });
        }
    }
}
