package com.pokkt.wrapper.thirdparty.AdMob;

import android.app.Activity;
import android.content.Context;
import android.os.Bundle;
import android.os.Handler;
import android.os.Looper;
import android.text.TextUtils;
import android.util.Log;

import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.mediation.MediationAdRequest;
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitial;
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitialListener;
import com.pokkt.PokktAds;

import org.json.JSONObject;

public class PokktCustomInterstitial implements CustomEventInterstitial, PokktAds.Interstitial.InterstitialDelegate, PokktAds.VideoAd.VideoAdDelegate {

    private final String TAG = "PokktAdMobWrapperInter";
    private CustomEventInterstitialListener interstitialListener = null;
    private int isAdAvailable = 0;//1 video ad available, 2 interstitial available
    private String screenName = "Default";
    private String appId = "";
    private String secKey = "";
    private String thirdPartyUserid = "12345";
    private boolean isDebug = true;

    @Override
    public void requestInterstitialAd(final Context context, final CustomEventInterstitialListener listener, final String serverParameter, final MediationAdRequest mediationAdRequest, final Bundle customEventExtras) {

        try {
            if (!TextUtils.isEmpty(serverParameter)) {
                JSONObject serverExtraObj = new JSONObject(serverParameter);
                screenName = serverExtraObj.optString("POKKT_SCREEN_NAME", "Default").trim();
                appId = serverExtraObj.optString("POKKT_APP_ID", "").trim();
                secKey = serverExtraObj.optString("POKKT_SEC_KEY", "").trim();
                thirdPartyUserid = serverExtraObj.optString("POKKT_THIRD_PARTY_USERID", "12345").trim();
                isDebug = serverExtraObj.optBoolean("POKKT_DEBUG", true);
            }
        } catch (Throwable t) {
            if (isDebug) {
                Log.e(TAG, " Failed to parse server parameters: " + serverParameter);
            }
        }
        if (TextUtils.isEmpty(appId) || TextUtils.isEmpty(secKey)) {
            if (isDebug) {
                Log.e(TAG, "Invalid details. Abort request");
            }
            return;
        }
        if (isDebug) {
            Log.i(TAG, " Request Interstitial from wrapper");
        }
        interstitialListener = listener;
        PokktAds.setPokktConfig(appId, secKey, (Activity) context);
        PokktAds.setThirdPartyUserId(thirdPartyUserid);
        PokktAds.Debugging.shouldDebug(context, isDebug);
        PokktAds.Interstitial.setDelegate(this);
        PokktAds.VideoAd.setDelegate(this);

        //first try video.
        PokktAds.VideoAd.cacheNonRewarded(screenName);
    }

    @Override
    public void showInterstitial() {
        if (isDebug) {
            Log.i(TAG, "Show Interstitial from wrapper");
        }
        if (isAdAvailable == 1) {
            PokktAds.VideoAd.showNonRewarded(screenName);
        } else {
            PokktAds.Interstitial.showNonRewarded(screenName);
        }
    }

    @Override
    public void onDestroy() {

    }

    @Override
    public void onPause() {

    }

    @Override
    public void onResume() {

    }

    @Override
    public void interstitialCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
        if (isDebug) {
            Log.i(TAG, "Interstitial cached");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdLoaded();
                }
            });
        }
        isAdAvailable = 2;
    }

    @Override
    public void interstitialCachingFailed(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Interstitial caching failed " + errorMessage);
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdFailedToLoad(AdRequest.ERROR_CODE_NO_FILL);
                }
            });
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialDisplayed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial displayed");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdOpened();
                }
            });
        }
    }

    @Override
    public void interstitialFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Interstitial failed to show " + errorMessage);
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdClosed();
                }
            });
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialClosed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial closed");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdClosed();
                }
            });
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialSkipped(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial skipped");
        }
        isAdAvailable = 0;
    }

    @Override
    public void interstitialCompleted(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Interstitial completed");
        }
    }

    @Override
    public void interstitialGratified(String screenName, boolean isRewarded, double reward) {

    }

    @Override
    public void videoAdCachingCompleted(String screenName, boolean isRewarded, double rewardValue) {
        if (isDebug) {
            Log.i(TAG, "Video caching completed");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdLoaded();
                }
            });
        }
        isAdAvailable = 1;
    }

    @Override
    public void videoAdCachingFailed(String screenName, boolean isRewarded, String errorMessage) {
        //try for non rewarded interstitial
        if (isDebug) {
            Log.i(TAG, "Video caching failed " + errorMessage);
        }
        PokktAds.Interstitial.cacheNonRewarded(screenName);
    }

    @Override
    public void videoAdDisplayed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video displayed");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdOpened();
                }
            });
        }
    }

    @Override
    public void videoAdFailedToShow(String screenName, boolean isRewarded, String errorMessage) {
        if (isDebug) {
            Log.i(TAG, "Video failed to show " + errorMessage);
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdClosed();
                }
            });
        }
        isAdAvailable = 0;
    }

    @Override
    public void videoAdClosed(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video closed");
        }
        if (PokktCustomInterstitial.this.interstitialListener != null) {
            Handler handler = new Handler(Looper.getMainLooper());
            handler.post(new Runnable() {
                public void run() {
                    PokktCustomInterstitial.this.interstitialListener.onAdClosed();
                }
            });
        }
        isAdAvailable = 0;
    }

    @Override
    public void videoAdSkipped(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video skipped");
        }
        isAdAvailable = 0;
    }

    @Override
    public void videoAdCompleted(String screenName, boolean isRewarded) {
        if (isDebug) {
            Log.i(TAG, "Video completed");
        }
    }

    @Override
    public void videoAdGratified(String screenName, boolean isRewarded, double rewardValue) {

    }
}
